cgexplore.systems\_optimisation
===============================

.. automodule:: cgexplore.systems_optimisation

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      Chromosome
      ChromosomeGenerator
      FitnessCalculator
      Generation
      StructureCalculator
   
   


   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
      :nosignatures:
   
      define_angle
      define_bond
      define_cosine_angle
      define_lennardjones
      define_nonbonded
      define_pyramid_angle
      define_torsion
      element_from_type
      get_forcefield_from_dict
      get_neighbour_library
      yield_near_models
   
   

   
   
   



